sqlobject.tests.test_sqlite module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_sqlite module

class `sqlobject.tests.test_sqlite.` `SQLiteFactoryTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = sq_lite_factory_test
  property `name`
  `q` = sq_lite_factory_test
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlite.SQLiteFactoryTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'sq_lite_factory_test'

class `sqlobject.tests.test_sqlite.` `SQLiteTruedivTest`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = sq_lite_truediv_test
  `q` = sq_lite_truediv_test
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlite.SQLiteTruedivTest`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'sq_lite_truediv_test'
  property `value`

`sqlobject.tests.test_sqlite.` `do_select`()

`sqlobject.tests.test_sqlite.` `test_empty_string`()

`sqlobject.tests.test_sqlite.` `test_list_databases`()

`sqlobject.tests.test_sqlite.` `test_list_tables`()

`sqlobject.tests.test_sqlite.` `test_memorydb`()

`sqlobject.tests.test_sqlite.` `test_sqlite_aggregate`()

`sqlobject.tests.test_sqlite.` `test_sqlite_factory`()

`sqlobject.tests.test_sqlite.` `test_sqlite_factory_str`()

`sqlobject.tests.test_sqlite.` `test_sqlite_threaded`()

`sqlobject.tests.test_sqlite.` `test_truediv`()